<?php



if ( ! defined( 'ABSPATH' ) ) { 

    exit; 

}





if ( ! class_exists( 'BindCommerce_API' ) ) {





    /**

     * 

     * BindCommerce_API main class

     * 

     * @since 1.0.0

     * 

     */

    class BindCommerce_API extends BindCommerce {        



        /**

         * 

         * Import API data

         * 

         * @since 1.0.0

         * 

         */       

        private static function import( $api_connector = "", $api_content_type = "text/xml", $api_token = "" ){    

        

            $api_connector_url = "";

        

            if ( empty($api_token) ) {

        

                $api_token = BindCommerce_Setting::get_api_token();

        

                if ($api_token == "") {



                    BindCommerce_Logger::error( __("Nessun token configurato", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

        

                    return json_encode([

                        "status"    => "error",

                        "message"   => __("Nessun token configurato", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                    ]);

        

                }

        

            }



            if ($api_connector == "order") {

        

                $api_connector_url = BindCommerce_Setting::get_api_connector_import_orders();

        

                if ( empty($api_connector_url) ) {

        

                    BindCommerce_Logger::error( __("Nessun connettore configurato per l'importazione degli ordini", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



                    return json_encode([

                        "status"    => "error",

                        "message"   => __("Nessun connettore configurato per l'importazione degli ordini", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                    ]);

        

                }



            }



            if ( empty($api_connector) ) {



                BindCommerce_Logger::error( __("Non è stato impostato nessun tipo di importazione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



                return json_encode([

                    "status"    => "error",

                    "message"   => __("Non è stato impostato nessun tipo di importazione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                ]);



            }



            if (!extension_loaded('curl')) {

                

                BindCommerce_Logger::error( __("Devi abilitare l'estensione cURL sul tuo server per utilizzare tutte le funzionalità del plugin bindCommerce.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



                return json_encode([

                    "status"    => "error",

                    "message"   => __("Devi abilitare l'estensione cURL sul tuo server per utilizzare tutte le funzionalità del plugin bindCommerce.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                ]);



            }

            if (!ini_get('allow_url_fopen')) {



                BindCommerce_Logger::error( __("Devi abilitare l'opzione allow_url_fopen sul tuo server per utilizzare tutte le funzionalità del plugin bindCommerce.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



                return json_encode([

                    "status"    => "error",

                    "message"   => __("Devi abilitare l'opzione allow_url_fopen sul tuo server per utilizzare tutte le funzionalità del plugin bindCommerce.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                ]);



            }



            $curl = curl_init();



            curl_setopt_array($curl, array(



                CURLOPT_URL => $api_connector_url,

                CURLOPT_SSL_VERIFYHOST => true,

                CURLOPT_RETURNTRANSFER => true,

                CURLOPT_HTTPHEADER => array(

                    "cache-control: no-cache",

                    "token: " . $api_token

                )          



            ));

          

            $response = curl_exec($curl);

            $error    = curl_error($curl);

            curl_close($curl);

            

            if ($error) {



                BindCommerce_Logger::error( "cURL Error #:" . $error );

                                

                return json_encode([

                    "status"    => "error",

                    "message"   => "cURL Error #:" . $error

                ]);



            } else {



                if ($response) {



                    return $response;



                }

                

                BindCommerce_Logger::error( __("Nessuna risposta dal server", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

                

                return json_encode([

                    "status"    => "error",

                    "message"   => __("Nessuna risposta dal server", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                ]);





            }   



            

        }





        /**

         * 

         * Import orders from bindCommerce

         * 

         * @since 1.0.0

         * 

         */ 

        public static function import_orders($order_ids = "-1", $limit = "", $order_by = "", $import_new_orders = false ) {



            // Check if order states are mapped

            if (!BindCommerce_Mapping::get_order_states_mapped()) {



                BindCommerce_Logger::warning( __("Non è stato impostato nessun mapping per gli stati d'ordine", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



            }



            if ($order_ids == "-1") {

                    

                $orders = self::import("order");



                if (BindCommerce_Tools::is_valid_xml($orders)) {



                    return BindCommerce_Order::insert_orders($orders, $limit, $order_by, $import_new_orders);



                }



                return json_encode( [

                    "status"    => "error",

                    "message"   => $orders,

                ]); 

                

            }



            return json_encode( [

                "status"    => "error",

                "message"   => __("Impossibile effettuare l'importazione di ordini", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),

            ]);



        }





        /**

         * 

         * Export API request

         * 

         * @since 1.0.0

         * 

         */       

        private static function export( $api_fields, $api_connector = "", $api_content_type = "text/xml", $api_token = "" ){    

        

            $api_connector_url = "";

        

            if ( empty($api_token) ) {

        

                $api_token = BindCommerce_Setting::get_api_token();

        

                if ($api_token == "") {

        

                    BindCommerce_Logger::error( __("Nessun token configurato", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



                    return json_encode([

                        "status"    => "error",

                        "message"   => __("Nessun token configurato", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                    ]);

        

                }

        

            }



            if ($api_connector == "product") {

        

                $api_connector_url = BindCommerce_Setting::get_api_connector_export_products();

        

                if ($api_connector_url == "") {

        

                    BindCommerce_Logger::error( __("Nessun connettore configurato per l'esportazione dei prodotti", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



                    return json_encode([

                        "status"    => "error",

                        "message"   => __("Nessun connettore configurato per l'esportazione dei prodotti", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                    ]);

        

                }



            }



            if ( empty($api_connector) ) {



                BindCommerce_Logger::error( __("Non è stato impostato nessun tipo di esportazione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



                return json_encode([

                    "status"    => "error",

                    "message"   => __("Non è stato impostato nessun tipo di esportazione", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                ]);



            }        



            if (!extension_loaded('curl')) {

                

                BindCommerce_Logger::error( __("Devi abilitare l'estensione cURL sul tuo server per utilizzare tutte le funzionalità del plugin bindCommerce.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



                return json_encode([

                    "status"    => "error",

                    "message"   => __("Devi abilitare l'estensione cURL sul tuo server per utilizzare tutte le funzionalità del plugin bindCommerce.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                ]);



            }

            if (!ini_get('allow_url_fopen')) {



                BindCommerce_Logger::error( __("Devi abilitare l'opzione allow_url_fopen sul tuo server per utilizzare tutte le funzionalità del plugin bindCommerce.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

                

                return json_encode([

                    "status"    => "error",

                    "message"   => __("Devi abilitare l'opzione allow_url_fopen sul tuo server per utilizzare tutte le funzionalità del plugin bindCommerce.", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                ]);



            }



            $curl = curl_init();



            curl_setopt_array($curl, array(



                CURLOPT_URL => $api_connector_url,

                CURLOPT_RETURNTRANSFER => true,

                CURLOPT_ENCODING => "",

                CURLOPT_MAXREDIRS => 10,

                CURLOPT_TIMEOUT => 30,

                CURLOPT_HTTP_VERSION => CURL_HTTP_VERSION_1_1,

                CURLOPT_CUSTOMREQUEST => "POST",

                CURLOPT_HTTPHEADER => array(

                    "cache-control: no-cache",

                    "content-type: " . $api_content_type,

                    "token: " . $api_token

                ),

                CURLOPT_POSTFIELDS => $api_fields["postfields"]            



            ));

          

            $response = curl_exec($curl);

            $error    = curl_error($curl);

            curl_close($curl);

            

            if ($error) {



                BindCommerce_Logger::error( "cURL Error #:" . $error );

                

                return json_encode([

                    "status"    => "error",

                    "message"   => "cURL Error #:" . $error

                ]);



            } else {



                if ($response) {



                    global $wpdb;

                                    

                    if ($api_connector == "product") {



                        // Insert products 

                        $table_name = BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_SYNC_EXPORT_PRODUCTS;

                        $insert_products = $api_fields["product_create_sync_codes"];



                        foreach ($insert_products as $product ) {



                            foreach ($product as $product_id => $product_sku ) {



                                $sync_id = BindCommerce_DB::get_result("



                                    SELECT  sync_id 

                                    FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_SYNC_EXPORT_PRODUCTS . " " . "

                                    WHERE   woocommerce_product_id  = '" . $product_id  . "'

                                    AND     bindcommerce_product    = '" . $product_sku . "';



                                ");



                                if ( empty($sync_id) ) {



                                    $wpdb->insert( $table_name, [

                                            'woocommerce_product_id'    => $product_id,

                                            'bindcommerce_product'      => $product_sku

                                        ]

                                    ); 



                                }



                            }



                        }



                        

                        // Delete products 

                        $delete_products   = $api_fields["product_delete_sync_codes"];



                        foreach ($delete_products as $product ) {



                            foreach ($product as $product_id => $product_sku ) {



                                $sync_id = BindCommerce_DB::get_result("



                                    SELECT  sync_id 

                                    FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_SYNC_EXPORT_PRODUCTS . " " . "

                                    WHERE   woocommerce_product_id  = '" . $product_id . "'

                                    AND     bindcommerce_product    = '" . $product_sku . "';



                                ");



                                if ( !empty($sync_id) ) {



                                    $wpdb->delete( $table_name, [

                                            'woocommerce_product_id'    => $product_id,

                                            'bindcommerce_product'      => $product_sku

                                        ]

                                    ); 



                                }



                            }



                        }





                    }



                    return $response;



                }

                

                BindCommerce_Logger::error( __("Nessuna risposta dal server", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );

                

                return json_encode([

                    "status"    => "error",

                    "message"   => __("Nessuna risposta dal server", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                ]);





            }   



            

        } 





        /**

         * 

         * Export products via API to BindCommerce

         * 

         * @since 1.0.0

         * 

         */

        public static function export_products( $products_id, $limit = "", $order_by = "", $mode = "", $format = "text/xml", $debug = false, $type = "incremental" ){ 



            $products = BindCommerce_Product::get_products_trace([

                "products_id"   => $products_id,

                "limit"         => $limit,

                "order_by"      => $order_by,

                "mode"          => $mode,

                "format"        => $format,

                "debug"         => $debug,

                "type"          => $type

            ]);



            if ($debug) {



                return $products;



            }

            

            if ($products) {



                return self::export(

                    $products,

                    "product"

                ); 



            }



            BindCommerce_Logger::error( __("Impossibile effettuare la Sync Prodotto", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) );



            return json_encode( [

                "status"    => "error",

                "message"   => __("Impossibile effettuare la Sync Prodotto", BINDCOMMERCE_PLUGIN_TEXT_DOMAIN),

            ]);



        }





    }



}





?>