<?php



if (!defined("ABSPATH")) { 

    exit; 

}





if (!class_exists("BindCommerce_Setting")) {



    /**

     * 

     * The main BindCommerce Settings class

     *

     * @since 1.0.0

     * 

     */ 

    class BindCommerce_Setting extends BindCommerce {    





        /**

         * 

         * Update option

         * 

         * @since 1.0.0

         * 

         */

        public static function update_option($option_name, $option_value) {



            global $wpdb;           



            $result = $wpdb->update(

                $wpdb->prefix . BINDCOMMERCE_DB_TABLE_OPTIONS, 

                [

                    "option_value" => $option_value

                ], 

                [

                    "option_name"  => $option_name

                ]

            );

            

            if (!$result) {



                return ($wpdb->last_error);



            }    



            return true;

            

        }





        /**

         * 

         * Get api connector for import orders from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_api_connector_import_orders() {



            return BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_api_connector_import_orders';



            "); 



        }





        /**

         * 

         * Get api connector for export orders from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_api_connector_export_products() {



            return BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_api_connector_export_products';



            "); 



        }





        /**

         * 

         * Get api token from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_api_token() {



            return BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_api_token';



            ");



        }





        /**

         * 

         * Get api token from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_cron_token() {



            $cron_token = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_cron_token';



            ");



            if ( !empty($cron_token) ) {

                return $cron_token;

            } 



            return false;  



        }

       



        /**

         * 

         * Check from options if sync is available when product is saved

         * 

         * @since 1.0.0

         * 

         */

        public static function get_sync_product_edit_status() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_products_sync_edit_product_status';



            ");

            

            if ($result == 1) {

                return true;

            } 



            return false;    

            

        }

        



        /**

         * 

         * Check if drafts product can be exported

         * 

         * @since 1.0.1

         * 

         */

        public static function get_export_draft_products_status() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_products_export_drafts';



            ");

            

            if ($result == 1) {

                return true;

            } 



            return false;    

            

        }

        



        /**

         * 

         * Get the gtin field status from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_gtin_fields_status() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_gtin_fields';



            ");

            

            if ($result == 1) {

                return true;

            }



            return false;    

            

        }





        /**

         * 

         * Get the gtin front-end field status from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_gtin_front_end_fields_status() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_gtin_front_end_fields';



            ");

            

            if ($result == 1) {

                return true;

            }



            return false;    

            

        }





        /**

         * 

         * Get product prefix from options

         * 

         * @since 1.0.0

         * 

         */        

        public static function get_product_mode() {



            return BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_products_import_mode';



            ");



        }





        /**

         * 

         * Returns product mode id status

         * 

         * @since 1.0.0

         * 

         */        

        public static function is_product_mode_id() {



            $modes = (array)unserialize( BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_products_import_mode';



            ") );



            

            foreach ( $modes as $mode => $value ) {



                if ($mode == "id" && $value == true) {

                    

                    return true; 

                    

                }

                    

            }

        

            return false;



        }





        /**

         * 

         * Returns product mode sku status

         * 

         * @since 1.0.0

         * 

         */        

        public static function is_product_mode_sku() {



            $modes = (array)unserialize( BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_products_import_mode';



            ") );

            

            foreach ( $modes as $mode => $value ) {



                if ($mode == "cod" && $value == true) {

                    

                    return true; 

                    

                }

                    

            }

        

            return false;



        }





        /**

         * 

         * Get product prefix status from options

         * 

         * @since 1.0.0

         * 

         */        

        public static function get_product_prefix_status() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_products_import_prefix_status';



            ");



            if ($result == 1) {

                return true;

            }   



            return false;



        }





        /**

         * 

         * Get product prefix from options

         * 

         * @since 1.0.0

         * 

         */        

        public static function get_product_prefix() {



            $product_prefix = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_products_import_prefix';



            ");



            if ( !empty($product_prefix) ) {

                return $product_prefix;

            } 



            return false;





        }





        /**

         * 

         * Get product tax amount status from options

         * 

         * @since 1.0.0

         * 

         */ 

        public static function get_tax_amount_status() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_status = '1'

                AND option_name = 'bindcommerce_products_tax_status_amount';



            ");

            

            if ($result == 1) {

                return true;

            }   



            return false;    

            

        }



        /**

         * 

         * Get product tax amount from options

         * 

         * @since 1.0.0

         * 

         */ 

        public static function get_tax_amount() {



            return BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_products_tax_value_amount';



            ");



        }





        /**

         * 

         * Get product supplement amount status from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_supplement_amount_status() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_status = '1'

                AND option_name = 'bindcommerce_products_supplement_status_amount';



            ");



            if ($result == 1) {

                return true;

            }    



            return false;    

            

        }





        /**

         * 

         * Get product supplement amount from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_supplement_amount() {



            return BindCommerce_DB::get_result("

            

                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_products_supplement_value_amount';



            ");



        }

        



        /**

         * 

         * Get product supplier mapping from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_product_supplier_mapping() {



            $option_value = BindCommerce_DB::get_result("

            

                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_mapping_product_supplier';



            ");



            $attributes = wc_get_attribute_taxonomies();



            if ( $attributes ) {



                if ($option_value != "") {



                    $attr_exist = false;

                    foreach ( $attributes as $attribute ) {



                        if ($option_value == $attribute->attribute_name) {



                            $attr_exist = true;

                            break;



                        }



                    }



                    if (!$attr_exist) {                                        

                        

                        BindCommerce_Setting::update_option("bindcommerce_mapping_product_supplier", "");

                        return false;



                    }



                }



                foreach ( $attributes as $attribute ) {



                    if ($option_value == $attribute->attribute_name) { 



                        return $option_value;



                    } 



                } 



            } else {



                if ($option_value != "") {

                    

                   BindCommerce_Setting::update_option("bindcommerce_mapping_product_supplier", "");

                   return false;



                }

                

            }

            

            return false;



        }





        /**

         * 

         * Get product manufacturer mapping from options

         * 

         * @since 1.0.0

         * 

         */

        public static function get_product_manufacturer_mapping() {



            $option_value = BindCommerce_DB::get_result("

            

                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_mapping_product_manufacturer';



            ");



            $attributes = wc_get_attribute_taxonomies();



            if ( $attributes ) {



                if ($option_value != "") {



                    $attr_exist = false;

                    foreach ( $attributes as $attribute ) {



                        if ($option_value == $attribute->attribute_name) {



                            $attr_exist = true;

                            break;



                        }



                    }



                    if (!$attr_exist) {                                        

                        

                        BindCommerce_Setting::update_option("bindcommerce_mapping_product_manufacturer", "");

                        return false;



                    }



                }



                foreach ( $attributes as $attribute ) {



                    if ($option_value == $attribute->attribute_name) { 



                        return $option_value;



                    } 



                } 



            } else {



                if ($option_value != "") {

                    

                   BindCommerce_Setting::update_option("bindcommerce_mapping_product_manufacturer", "");

                   return false;



                }

                

            }

            

            return false;



        }



        





        /**

         * 

         * Get force order status from options

         * 

         * @since 1.0.0

         * 

         */ 

        public static function get_force_order_status() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_status = '1'

                AND option_name = 'bindcommerce_orders_force_order_import';



            ");

            

            if ($result == 1) {

                return true;

            }   



            return false;    

            

        }





        /**

         * 

         * Check if debug mode is active

         * 

         * @since 1.0.0

         * 

         */        

        public static function is_debug_mode() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_status = '1'

                AND option_name = 'bindcommerce_debug_mode';



            ");



            if ($result == 1) {

                return true;

            }

            

            return false;



        }    





        /**

         * 

         * Check if debug mode view is enabled

         * 

         * @since 1.0.0

         * 

         */        

        public static function is_debug_mode_view_enabled() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_status = '1'

                AND option_name = 'bindcommerce_debug_mode_view';



            ");



            if ($result == 1) {

                return true;

            }



            return false;



        }

        



        /**

         * 

         * Check if notify by email is enabled

         * 

         * @since 1.0.1

         * 

         */

        public static function is_debug_notify_email_enabled() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_debug_notify_email';



            ");

            

            if ($result == 1) {

                return true;

            } 



            return false;    

            

        }

        



        /**

         * 

         * Get notify emails

         * 

         * @since 1.0.1

         * 

         */

        public static function get_debug_notify_email_list() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . DB_NAME . "." . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_debug_notify_email_list';



            ");

            

            if (!empty($result)) {

                return $result;

            } 



            return false;    

            

        }





        /**

         * 

         * Check if delete all data is enabled

         * 

         * @since 1.0.0

         * 

         */        

        public static function is_delete_all_data_enabled() {



            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_delete_all_data_after_uninstall';



            ");



            if ($result == 1) {

                return true;

            }



            return false;



        }





    }



}





?>