<?php



if (!defined("ABSPATH")) { 

    exit; 

}





if (!class_exists("BindCommerce_Setup")) {



    /**

     * 

     * The main BindCommerce Setup class

     *

     * @since 1.0.1

     * 

     */ 

    class BindCommerce_Setup extends BindCommerce {

      



        /**

         * 

         * Create Database tables

         * 

         * @since 1.0.1

         * 

         */

        private static function create_tables() {

            

            require_once(BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-create-table-bindcommerce-options.php");

            require_once(BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-create-table-bindcommerce-mapping-import-orders.php");

            require_once(BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-create-table-bindcommerce-sync-import-orders.php");

            require_once(BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-create-table-bindcommerce-sync-export-products.php");

            

        }





        /**

         * 

         * Delete Database tables

         * 

         * @since 1.0.1

         * 

         */

        public static function delete_tables() {

            

            require_once(BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-delete-table-bindcommerce-options.php");

            require_once(BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-delete-table-bindcommerce-mapping-import-orders.php");

            require_once(BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-delete-table-bindcommerce-sync-import-orders.php");

            require_once(BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-delete-table-bindcommerce-sync-export-products.php");

            

        }



        

        /**

         * 

         * Delete all user meta

         * 

         * @since 1.0.1

         * 

         */

        public static function delete_all_product_meta() {



            $query = new WC_Product_Query( array(

                "return"        => "ids", 

                "limit"         => -1,

            ) );

            $all_product_ids = $query->get_products();



            foreach ( $all_product_ids as $product_id ) {



                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_SYNC );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_SIMPLE_REGULAR_PRICE );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_SIMPLE_QUANTITY );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_SIMPLE_TAX_AMOUNT );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_SIMPLE_SUPPLEMENT_AMOUNT );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_SIMPLE_GTIN );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_VARIATION_REGULAR_PRICE );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_VARIATION_QUANTITY );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_VARIATION_TAX_AMOUNT );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_VARIATION_SUPPLEMENT_AMOUNT );

                delete_post_meta( $product_id, BINDCOMMERCE_PRODUCT_META_VARIATION_GTIN );



            }



        }





        /**

         * 

         * Create Default Table records

         * 

         * @since 1.0.1

         * 

         */

        public static function create_default_records() {         

            

            require_once( BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-insert-table-bindcommerce-options.php");

            

        }





        /**

         * 

         * Reset Database tables

         * 

         * @since 1.0.1

         * 

         */

        public static function reset_tables() {

            

            self::delete_tables();

            self::create_tables();

            self::create_default_records();

            

        }





        /**

         * 

         * Reset Database tables and metadata

         * 

         * @since 1.0.1

         * 

         */

        public static function reset_tables_and_data() {

            

            self::delete_all_product_meta();

            self::delete_tables();

            self::create_tables();

            self::create_default_records();

            

        }





        /**

         * 

         * Reset Settings and Mappings

         * 

         * @since 1.0.1

         * 

         */

        public static function reset_settings() {

            

            require_once( BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-delete-table-bindcommerce-options.php");

            require_once( BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-create-table-bindcommerce-options.php");

            require_once( BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-insert-table-bindcommerce-options.php");

            require_once( BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-delete-table-bindcommerce-mapping-import-orders.php");

            require_once( BINDCOMMERCE_PLUGIN_PATH . "includes/sql/sql-create-table-bindcommerce-mapping-import-orders.php");

                        

        }



        

        /**

         * 

         * Install all tables and default records

         * 

         * @since 1.0.1

         * 

         */

        public static function install() {

            

            self::create_tables();

            self::create_default_records();

            

        }        



        

        /**

         * 

         * Update plugin data

         * 

         * @since 1.0.1

         * 

         */

        public static function upgrade() {



            self::update_version();

            

            include_once( BINDCOMMERCE_PLUGIN_PATH . "includes/upgrades/upgrade-bindcommerce-v" . BINDCOMMERCE_PLUGIN_VERSION . ".php");

            

        }

        



        /**

         * 

         * Update plugin version in Database

         * 

         * @since 1.0.1

         * 

         */

        public static function update_version() {

            

            global $wpdb;



            $data = [ 

                "option_value" => BINDCOMMERCE_PLUGIN_VERSION

            ];               



            $where = [ 

                "option_name" => "bindcommerce_plugin_version_saved"

            ];



            $wpdb->update(

                BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS, 

                $data, 

                $where 

            );



        }





    }



}