<?php



if ( ! defined( 'ABSPATH' ) ) { 

    exit; 

}





if ( ! class_exists( 'BindCommerce' ) ) {



    /**

     * 

     * The BindCommerce main class

     * 

     * @since 1.0.0

     * 

     */

    class BindCommerce {





        /**

         * 

         * Check updates, compatibility and data.

         * 

         * @since 1.0.0

         * 

         */

        public static function check() {



            self::check_compatibility();

            self::check_installed_updated();       



        }





        /**

         * 

         * Check if the bindCommerce plugin is compatible with the current system.

         * 

         * @since 1.0.0

         * 

         */

        public static function check_compatibility() {

        

            $errors = [];

        

            if ( version_compare(PHP_VERSION, BINDCOMMERCE_REQUIRED_PHP_VERSION, '<') ) { 



                $errors[] =  __('- Per poter funzionare correttamente bindCommerce richiede una versione PHP ', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) 

                            . BINDCOMMERCE_REQUIRED_PHP_VERSION

                            . __(' o successiva. La versione PHP attualmente in uso è la ', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                            . phpversion();

                    

            } 



            if ( !class_exists( 'WooCommerce' ) ) {



                $errors[] =  __('- Per poter attivare correttamente il plugin bindCommerce è necessario installare e attivare il plugin WooCommerce.', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN);

            

            } else {

                

                global $woocommerce;



                if ( version_compare( $woocommerce->version, BINDCOMMERCE_REQUIRED_WC_VERSION, "<=" ) ) {

                    

                    $errors[] =  __('- Per poter funzionare correttamente bindCommerce richiede una versione di WooCommerce ', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN) 

                                . BINDCOMMERCE_REQUIRED_WC_VERSION

                                . __(' o successiva. La versione WooCommerce attualmente in uso è la ', BINDCOMMERCE_PLUGIN_TEXT_DOMAIN)

                                . $woocommerce->version;                             

                    

                }



            }        



            if (empty($errors)) {

                return true;

            }



            foreach ($errors as $error) {

                echo $error . "<br />";

            }

            

            exit;



        }





        /**

         * 

         * Activate plugin

         * 

         * @since 1.0.0

         * 

         */

        public static function activate_plugin() {

        

            BindCommerce::check();

            BindCommerce_Setup::install();

            do_action( "bindcommerce_plugin_activated" );

                

        }





        /**

         * 

         * Deactivate plugin

         * 

         * @since 1.0.0

         * 

         */

        public static function deactivate_plugin() {             

            

            do_action( "bindcommerce_plugin_deactivated" );



        }





        /**

         * 

         * Upgrade tables and data

         * 

         * @since 1.0.1

         * 

         */

        public static function upgrade_plugin() {



            BindCommerce_Setup::upgrade();

                        

            do_action( "bindcommerce_plugin_updated" );

                

        }





        /**

         * 

         * Delete tables and custom meta data

         * 

         * @since 1.0.0

         * 

         */

        public static function delete_plugin() {



            if (BindCommerce_Setting::is_delete_all_data_enabled()) {

                BindCommerce_Setup::delete_tables();

            }

            

            do_action( "bindcommerce_plugin_eliminated" );

                

        }





        /**

         * 

         * Get plugin version stored in Database

         * 

         * @since 1.0.1

         * 

         */

        public static function get_version_saved() {

            

            $result = BindCommerce_DB::get_result("



                SELECT option_value 

                FROM " . BINDCOMMERCE_DB_WP_PREFIX . BINDCOMMERCE_DB_TABLE_OPTIONS . " " . "

                WHERE option_name = 'bindcommerce_plugin_version_saved';



            ");

            

            if (!empty($result)) {

                return $result;

            }   



            return 0;



        }





        /**

         * 

         * Check new installed updated

         * 

         * @since 1.0.1

         * 

         */

        public static function check_installed_updated() {

                        

            $current_version_saved = self::get_version_saved();



            if ( version_compare( $current_version_saved, BINDCOMMERCE_PLUGIN_VERSION, "<" ) ) {



                self::upgrade_plugin();



            }



        }





    }





}







?>